diff --git a/tools/Texture_Converter.py b/tools/Texture_Converter.py
index 80fafa090..1fb8d926f 100755
--- a/tools/Texture_Converter.py
+++ b/tools/Texture_Converter.py
@@ -14,13 +14,26 @@
# - Put extracted texture pack into $HOME/tmp/pp
# - Make sure the file “Texture_Conversion_Table.csv” is in the same directory as the script
# - Run the script in its directory
# - If everything worked, retrieve texture pack in texture_pack/
__author__ = "Wuzzy"
__license__ = "MIT License"
__status__ = "Development"
+import shutil, csv, os, tempfile, sys, getopt
+from PIL import Image
+
+# Helper vars
+home = os.environ["HOME"]
+mineclone2_path = home + "/.minetest/games/mineclone2"
+working_dir = os.getcwd()
+output_dir_name = "New_MineClone_2_Texture_Pack"
+
### SETTINGS ###
+output_dir = working_dir
+
+base_dir = None
+
# If True, will only make console output but not convert anything.
dry_run = False
@@ -31,16 +44,67 @@ make_texture_pack = True
# If True, prints all copying actions
verbose = False
+syntax_help = """TextureConverter.py -i [-o
@@ -14,13 +14,26 @@
# - Make sure the file “Texture_Conversion_Table.csv” is in the same directory as the script
# - Run the script in its directory
-# - If everything worked, retrieve texture pack in texture_pack/
+# - If everything worked, retrieve texture pack in New_MineClone_2_Texture_Pack/
__author__ = "Wuzzy"
__license__ = "MIT License"